Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4754)

Unified Diff: chrome/browser/banners/app_banner_manager.cc

Issue 1131993005: Switch //chrome/browser code to use IsOriginSecure() instead of SchemeIsSecure(). (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebasin' like it's mah job. Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/content_settings/permission_context_uma_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/banners/app_banner_manager.cc
diff --git a/chrome/browser/banners/app_banner_manager.cc b/chrome/browser/banners/app_banner_manager.cc
index 6fdd5cf1c0fea885c956f7c3bb58acf210e62c43..fd3e65bc8e379ea08ff0f52ce8a964f75c9c7a30 100644
--- a/chrome/browser/banners/app_banner_manager.cc
+++ b/chrome/browser/banners/app_banner_manager.cc
@@ -11,6 +11,7 @@
#include "content/public/browser/render_frame_host.h"
#include "content/public/browser/web_contents.h"
#include "content/public/common/frame_navigate_params.h"
+#include "content/public/common/origin_util.h"
#include "net/base/load_flags.h"
#include "ui/gfx/screen.h"
@@ -47,9 +48,9 @@ void AppBannerManager::DidFinishLoad(
return;
}
// A secure scheme is required to show banners, so exit early if we see the
// URL is invalid.
- if (!validated_url.SchemeIsSecure() && !gDisableSecureCheckForTesting)
+ if (!content::IsOriginSecure(validated_url) && !gDisableSecureCheckForTesting)
return;
// Kick off the data retrieval pipeline.
« no previous file with comments | « no previous file | chrome/browser/content_settings/permission_context_uma_util.cc » ('j') | no next file with comments »
@@ -47,9 +48,9 @@ void AppBannerManager::DidFinishLoad(
return;
}
- // A secure scheme is required to show banners, so exit early if we see the
+ // A secure origin is required to show banners, so exit early if we see the
// URL is invalid.

Powered by Google App Engine
This is Rietveld 408576698